from . import _lzham


class LZHAMCompressor:

    def __init__(self, filters=None):
        self.kwargs = {}
        self._reinit = False
        self.parse_filters(filters)
        self._handler = _lzham.lzham_compress_init(**self.kwargs)

    def reinit(self):
        self._handler = _lzham.lzham_compress_reinit(self._handler)
        self._reinit = False

    def parse_filters(self, filters):
        if filters is not None:
            _args = [
                     'dict_size_log2',
                     'level',
                     'table_update_rate',
                     'max_helper_threads',
                     'table_max_update_interval',
                     'table_update_interval_slow_rate'
                     ]

            for arg in _args:
                if filters.get(arg) is not None:
                    self.kwargs[arg] = filters[arg]

    def compress(self, data):
        if self._reinit:
            self.reinit()

        self._reinit = True
        return _lzham.lzham_compress(self._handler, data)


def compress(data, filters=None):
    return LZHAMCompressor(filters).compress(data)



from . import _lzham


class LZHAMDecompressor:

    def __init__(self, filters=None):
        self.kwargs = {}
        self._reinit = False
        self.parse_filters(filters)
        self._handler = _lzham.lzham_decompress_init(**self.kwargs)

    def reinit(self, filters=None):
        self.parse_filters(filters)
        self._handler = _lzham.lzham_decompress_reinit(self._handler, **self.kwargs)
        self._reinit = False

    def parse_filters(self, filters):
        if filters is not None:
            _args = [
                     'dict_size_log2',
                     'table_update_rate',
                     'table_max_update_interval',
                     'table_update_interval_slow_rate',
                     'compute_adler32_during_decomp',
                     'unbuffered_decompression'
                     ]

            for arg in _args:
                if filters.get(arg) is not None:
                    self.kwargs[arg] = filters[arg]

    def decompress(self, data, uncompressed_size):
        if self._reinit:
            self.reinit(self.kwargs)

        self._reinit = True
        return _lzham.lzham_decompress(self._handler, data, uncompressed_size)


def decompress(data, uncompressed_size, filters=None):
    return LZHAMDecompressor(filters).decompress(data, uncompressed_size)



import platform

from setuptools import setup, Extension


ext_sources = [
               'src/lzham_module.cpp',
               'src/lib/lzham_api.cpp',
               'src/lib/lzham_assert.cpp',
               'src/lib/lzham_checksum.cpp',
               'src/lib/lzham_huffman_codes.cpp',
               'src/lib/lzham_lzbase.cpp',
               'src/lib/lzham_lzcomp.cpp',
               'src/lib/lzham_lzcomp_internal.cpp',
               'src/lib/lzham_lzcomp_state.cpp',
               'src/lib/lzham_lzdecomp.cpp',
               'src/lib/lzham_lzdecompbase.cpp',
               'src/lib/lzham_match_accel.cpp',
               'src/lib/lzham_mem.cpp',
               'src/lib/lzham_platform.cpp',
               'src/lib/lzham_prefix_coding.cpp',
               'src/lib/lzham_symbol_codec.cpp',
               'src/lib/lzham_timer.cpp',
               'src/lib/lzham_vector.cpp',
               ]

if platform.system() == 'Windows':
    ext_sources.append('src/lib/lzham_win32_threading.cpp')

else:
    ext_sources.append('src/lib/lzham_pthreads_threading.cpp')

with open('README.md', 'r') as f:
    long_description = f.read()

setup(name='pylzham',
      version='0.1.3',
      author='GaLaXy1036',
      description='Python 3 Wrapper for LZHAM Codec',
      long_description=long_description,
      long_description_content_type='text/markdown',
      url='https://github.com/Galaxy1036/pylzham',
      ext_modules=[Extension('_lzham',
                             ext_sources)],
      ext_package='lzham',
      package_dir={'': 'src'},
      packages=['', 'lzham'],
      license='MIT',
      classifiers=[
                   'Programming Language :: Python :: 3',
                   'License :: OSI Approved :: MIT License',
                   'Operating System :: OS Independent',
                   ]
      )
